Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(515)

Unified Diff: src/compiler/js-graph.h

Issue 1186033006: [turbofan] Introduce DeadValue and DeadEffect operators. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Addressed comments. Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/graph-visualizer.cc ('k') | src/compiler/js-graph.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/js-graph.h
diff --git a/src/compiler/js-graph.h b/src/compiler/js-graph.h
index dda1277419437389e9dcd46a29e7eedad4f5e2f9..b6b1322f331c9a0c1fd508a7e5245eed61f96ebf 100644
--- a/src/compiler/js-graph.h
+++ b/src/compiler/js-graph.h
@@ -117,7 +117,10 @@ class JSGraph : public ZoneObject {
// cannot deopt.
Node* EmptyFrameState();
- // Create a control node that serves as control dependency for dead nodes.
+ // Creates a value node that servers as value input for dead nodes.
+ Node* DeadValue();
+
+ // Creates a control node that serves as control dependency for dead nodes.
Node* DeadControl();
JSOperatorBuilder* javascript() const { return javascript_; }
@@ -142,6 +145,7 @@ class JSGraph : public ZoneObject {
kOneConstant,
kNaNConstant,
kEmptyFrameState,
+ kDeadValue,
kDeadControl,
kNumCachedNodes // Must remain last.
};
« no previous file with comments | « src/compiler/graph-visualizer.cc ('k') | src/compiler/js-graph.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698